==========
Developers
==========

- qrlcore developers:

#1 cyyber
309 commits  19,410 ++  16,048 --

#2 jleni
240 commits  72,648 ++  66,410 --

#3 surg0r
227 commits  10,857 ++  5,095 --

#4 scottdonaldau
29 commits  241,841 ++  240,315 --

#5 bidulemachin
13 commits  285 ++  57 --

#6 randomshinichi
10 commits  632 ++  481 --

#7 converghub
6 commits  204 ++  40 --

#8 jplomas
4 commits  33 ++  3 --

#9 Wyc0
4 commits  166 ++  11 --

#10 leagueofdelegates
4 commits  0 ++  0 --

#11 randomusergenerator
3 commits  173 ++  2 --

#12 nickycakes
3 commits  24 ++  18 --

#13 jomarip
2 commits  36 ++  0 --

#14 r41d
2 commits  11 ++  17 --

#15 timhovius
1 commit  2 ++  2 --

#16 fullmatches
1 commit  0 ++  0 --

#17 jackalyst
1 commit  1 ++  1 --

23/10/2017
